pub struct StatusBarPart<'a> { /* private fields */ }Available on crate feature
gui only.Expand description
A single part of a StatusBar control.
Note: Each object keeps the zero-based index of a part. If new parts are added/removed from the status bar control, the object may then point to a different item.
You cannot directly instantiate this object, it is created internally by the control.
Implementations
Sourceimpl<'a> StatusBarPart<'a>
impl<'a> StatusBarPart<'a>
Sourcepub fn set_icon(&self, hicon: Option<&HICON>) -> SysResult<Self>
pub fn set_icon(&self, hicon: Option<&HICON>) -> SysResult<Self>
Sets the icon of a part by sending an
SbSetIcon message.
Returns the same part, so further operations can be chained.